StandardSampler

Struct StandardSampler 

pub struct StandardSampler { /* private fields */ }
Selects a token after applying multiple SamplerStage’s to the probability distribution output by the model.

Implementations

Source

impl StandardSampler

pub fn new_softmax( stages: Vec<SamplerStage>, min_keep: usize, ) -> StandardSampler

Creates a new StandardSampler that modifies the model’s raw distribution using multiple SamplerStage’s, then selects a random token from that distrubution.

Ensures that at least min_keep tokens remain after the SamplerStage’s are applied.

pub fn new_greedy() -> StandardSampler

Creates a new StandardSampler that always selects the next most token produced by the model.

pub fn new_mirostat( stages: Vec<SamplerStage>, min_keep: usize, tau: f32, eta: f32, m: i32, ) -> StandardSampler

Creates a new StandardSampler that selects a token using Mirostat.

pub fn new_mirostat_v2( stages: Vec<SamplerStage>, min_keep: usize, tau: f32, eta: f32, ) -> StandardSampler

Creates a new StandardSampler that selects a token using Mirostat V2.